﻿
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

using SchedulerTest.Models;
using System.Web.Security;

using DHTMLX.Scheduler;
using DHTMLX.Scheduler.Controls;
using DHTMLX.Scheduler.Data;
using DHTMLX.Common;
namespace SchedulerTest.Controllers
{
    public class DifferentModesController : Controller
    {
        //
        // GET: /DifferentModes/

        public ActionResult YearNWeek()
        {
            var scheduler = new DHXScheduler(this);
          
            scheduler.Views.Clear();
            scheduler.Views.Add(new WeekView());
            scheduler.Views.Add(new YearView());
            scheduler.InitialView = (new YearView()).Name;
            scheduler.LoadData = true;
            scheduler.EnableDataprocessor = true;
            return View(scheduler);
        }
        public ActionResult GoogleMap()
        {
            var scheduler = new DHXScheduler(this);
      
            scheduler.Views.Clear();
            scheduler.Views.Add(new WeekView());
            scheduler.Views.Add(new MapView());
            scheduler.InitialView = (new MapView()).Name;
            scheduler.LoadData = true;
            //scheduler.EnableDataprocessor = true;
            scheduler.DataAction = "MapEvents";
            return View(scheduler);
        }



        public ActionResult MultipleResources()
        {
            var scheduler = new DHXScheduler(this);      
            
         
            scheduler.Config.details_on_create = true;
            scheduler.Config.details_on_dblclick = true;

            scheduler.Views.Clear();
            scheduler.Views.Add(new MonthView());
            var context = new DHXSchedulerDataContext();
            var unit = new UnitsView("unit1", "room_id");
            scheduler.Views.Add(unit);
            //can add IEnumerable of objects, native units or dictionary
            unit.AddOptions(context.Rooms);//parse model objects
            var timeline = new TimelineView("timeline", "room_id");
            timeline.RenderMode = TimelineView.RenderModes.Bar;
            var items = new List<object>();
            timeline.FitEvents = false;
            scheduler.Views.Add(timeline);
            timeline.AddOptions(context.Rooms);

            scheduler.InitialView = timeline.Name;

            scheduler.Lightbox.AddDefaults();
            var select = new LightboxSelect("room_id", "Room id");
            select.AddOptions(context.Rooms);
            scheduler.Lightbox.Add(select);

 
            //'Data' action is added by default, you can manage data sources by scheduler.Data.Loader.GetUrls collection     
            scheduler.Data.Loader.AddAction("OtherData");
            scheduler.Data.Loader.PreventCache();
            scheduler.LoadData = true;
            scheduler.InitialDate = new DateTime(2011, 9, 7);
            scheduler.EnableDataprocessor = true;
            return View(scheduler);
        }


        public ContentResult Data()
        {
            var data = new SchedulerAjaxData((new DHXSchedulerDataContext()).Events);
    
            return data;
        }

        public ContentResult OtherData()
        {
            var data = new SchedulerAjaxData(new CustomFieldsDataContext().ColoredEvents);
        
            return data;
        }
        public ContentResult MapEvents()
        {
            var today = DateTime.Today;

            var data = new SchedulerAjaxData(new List<object>() {
                new {id=2, text="Kurtzenhouse", start_date=today.AddDays(1).AddHours(13), end_date=today.AddDays(1).AddHours(16), lat=48.7396839, lng=7.813368099999934, event_location="D37, 67240 Kurtzenhouse, France"},
                new {id=3, text="Forêt Domaniale", start_date=today.AddDays(2).AddHours(10), end_date=today.AddDays(2).AddHours(12), lat=48.767333, lng=5.793258000000037, event_location="Forêt Domaniale de la Reine, Véry, 54200 Royaumeix, France"},         
                new {id=4, text="Windstein", start_date=today.AddDays(3).AddHours(7), end_date=today.AddDays(3).AddHours(8), lat=49.0003477, lng=7.687306499999977, event_location="1 Rue du Nagelsthal, 67110 Windstein, France"}
                });


            return data;
        }
       

        public ContentResult Save(int? id, FormCollection actionValues)
        {
            var action = new DataAction(actionValues);
            DHXSchedulerDataContext data = new DHXSchedulerDataContext();
            try
            {
                var changedEvent = (Event)DHXEventsHelper.Bind(typeof(Event), actionValues);
                switch (action.Type)
                {
                    case DataActionTypes.Insert:
                        data.Events.InsertOnSubmit(changedEvent);
                        break;
                    case DataActionTypes.Delete:
                        changedEvent = data.Events.SingleOrDefault(ev => ev.id == action.SourceId);
                        data.Events.DeleteOnSubmit(changedEvent);
                        break;
                    default:// "update"                          
                        var eventToUpdate = data.Events.SingleOrDefault(ev => ev.id == action.SourceId);
                        DHXEventsHelper.Update(eventToUpdate, changedEvent, new List<string>() { "id" });
                        break;
                }
                data.SubmitChanges();
                action.TargetId = changedEvent.id;
            }
            catch (Exception a)
            {
                action.Type = DataActionTypes.Error;
            }
            return (new AjaxSaveResponse(action));
        }
    }
}
